"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.processProjectGraph = void 0;
const devkit_1 = require("@nrwl/devkit");
const path = require("path");
const fileutils_1 = require("@nrwl/workspace/src/utils/fileutils");
const app_root_1 = require("@nrwl/workspace/src/utils/app-root");
const deps_utils_1 = require("./utils/deps-utils");
function isFlutterProject(project) {
    return fileutils_1.fileExists(path.join(app_root_1.appRootPath, project.root, 'pubspec.yaml'));
}
function getPackageInfosForNxFlutterProjects(workspace) {
    const workspacePackageInfo = {
        projects: {},
        packages: {}
    };
    Object.entries(workspace.projects).filter(([, project]) => isFlutterProject(project))
        .forEach(([projectName, project]) => {
        try {
            const pkgInfo = deps_utils_1.getPackageInfo(path.join(app_root_1.appRootPath, project.root));
            workspacePackageInfo.projects[projectName] = pkgInfo;
            workspacePackageInfo.packages[pkgInfo.packageId] = projectName;
        }
        catch (_a) {
            devkit_1.logger.warn(`[nx-flutter]: Failed to get package info for project '${projectName}'`);
        }
    });
    return workspacePackageInfo;
}
function addDependenciesForProject(rootProjectName, rootPkgInfo, builder, workspace) {
    devkit_1.logger.debug(`[nx-flutter]: Adding dependencies for project '${rootProjectName}'...`);
    rootPkgInfo.dependencies.forEach(depPkgInfo => {
        const depProjectName = workspace.packages[depPkgInfo.packageId];
        if (depProjectName) {
            builder.addDependency(devkit_1.DependencyType.static, rootProjectName, depProjectName);
        }
    });
}
function processProjectGraph(graph, context) {
    const builder = new devkit_1.ProjectGraphBuilder(graph);
    devkit_1.logger.debug('[nx-flutter]: Looking Flutter related projects inside the workspace...');
    const workspace = getPackageInfosForNxFlutterProjects(context.workspace);
    Object.entries(workspace.projects).forEach(([projectName, pkgInfo]) => {
        addDependenciesForProject(projectName, pkgInfo, builder, workspace);
    });
    return builder.getProjectGraph();
}
exports.processProjectGraph = processProjectGraph;
//# sourceMappingURL=project-graph.js.map